@@ -2,9 +2,10 @@ var dir_de06fbad444f0d6ad18055e8286d4c67 =
 [
     [ "__init__.py", "____init_____8py_source.html", null ],
     [ "_client.c", "__client_8c.html", "__client_8c" ],
-    [ "async_client.py", "async__client_8py.html", null ],
-    [ "client.py", "client_8py.html", "client_8py" ],
-    [ "database.py", "database_8py.html", "database_8py" ],
+    [ "async_client.py", "async__client_8py_source.html", null ],
+    [ "client.py", "client_8py_source.html", null ],
+    [ "config.py", "config_8py_source.html", null ],
+    [ "database.py", "database_8py_source.html", null ],
     [ "lirctool.py", "lirctool_8py_source.html", null ],
     [ "paths.py", "paths_8py_source.html", null ]
 ];
\ No newline at end of file
