@@ -30,11 +30,7 @@
 
 #include <sys/ioctl.h>
 
-#ifdef HAVE_KERNEL_LIRC_H
-#include <linux/lirc.h>
-#else
 #include "media/lirc.h"
-#endif
 
 #include "lirc/ir_remote.h"
 #include "lirc/driver.h"
