@@ -23,11 +23,7 @@
 #include <poll.h>
 #include <stdint.h>
 
-#ifdef HAVE_KERNEL_LIRC_H
-#include <linux/lirc.h>
-#else
 #include "media/lirc.h"
-#endif
 
 #include "lirc/driver.h"
 #include "lirc/lirc_log.h"
@@ -970,18 +966,6 @@ static ir_code get_data(struct ir_remote* remote, int bits, int done)
 
 	for (i = 0; i < bits; i++) {
 		code = code << 1;
-		if (is_goldstar(remote)) {
-			if ((done + i) % 2) {
-				log_trace1("$1");
-				remote->pone = remote->ptwo;
-				remote->sone = remote->stwo;
-			} else {
-				log_trace1("$2");
-				remote->pone = remote->pthree;
-				remote->sone = remote->sthree;
-			}
-		}
-
 		if (expectone(remote, done + i)) {
 			log_trace1("1");
 			code |= 1;
